<?php

declare(strict_types = 1);

namespace Drupal\workflow_state_permission;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\state_machine\Plugin\Workflow\WorkflowInterface;

/**
 * Service to check if changing workflow states is permitted for a given user.
 */
class WorkflowStatePermission implements WorkflowStatePermissionInterface {

  /**
   * The workflow state permission plugin manager.
   *
   * @var \Drupal\workflow_state_permission\WorkflowStatePermissionPluginManager
   */
  protected $pluginManager;

  /**
   * Constructs a WorkflowStatePermission service.
   *
   * @param \Drupal\workflow_state_permission\WorkflowStatePermissionPluginManager $pluginManager
   *   The workflow state permission plugin manager.
   */
  public function __construct(WorkflowStatePermissionPluginManager $pluginManager) {
    $this->pluginManager = $pluginManager;
  }

  /**
   * {@inheritdoc}
   */
  public function isStateUpdatePermitted(AccountInterface $account, EntityInterface $entity, WorkflowInterface $workflow, string $from_state, string $to_state): bool {
    foreach ($this->pluginManager->getDefinitions() as $definition) {
      /** @var \Drupal\workflow_state_permission\WorkflowStatePermissionPluginInterface $plugin */
      $plugin = $this->pluginManager->createInstance($definition['id']);
      if ($plugin->applies($entity)) {
        // The "$form_state === 'archived'" check is to allow the transition
        // from archived to '__new__' which is a fake transition that mainly
        // reverts the entity to the previous revision.
        $result = ($to_state !== '__new__' || $from_state === 'archived') && $plugin->isStateUpdatePermitted($account, $entity, $workflow, $from_state, $to_state);
        // Stop iterating as soon as any plugin denies access.
        if (!$result) {
          return FALSE;
        }
      }
    }
    return TRUE;
  }

}
